DataType

Struct DataType 

pub struct DataType { /* private fields */ }
DataType is just a String defining what data type is being used

Implementations

Source

impl DataType

pub fn valid(&self) -> Result<()>

Determine if a datatype specified in a flow is a valid datatype or not

Errors

Will return Err if self.string does not describe a valid DataType

pub fn is_array(&self) -> bool

Return if this datatype is an array or not

pub fn is_generic(&self) -> bool

Return true if this datatype is generic (not specified at compile time and can contain any other datatype) or not

pub fn array_type(&self) -> Option<DataType>

If an Array –> Return Option of the DataType the array holds If Generic –> Return Generic If not an Array –> Return None

pub fn type_array_order(&self) -> i32

Determine how deeply nested in arrays this DataType is. If not an array, returns 0

This is used at compile time by the compiler to determine the array order of an input or output

pub fn value_array_order(value: &Value) -> i32

Determine how deeply nested in arrays this serde_json::value::Value is. If not an array, returns 0

This is used at run time to determine the array order of an actual value being processed

pub fn compatible_types( from: &[DataType], to: &[DataType], from_subroute: &Route, ) -> Result<()>

For a set of output types to be compatible with a destination’s set of types ALL of the output_types must have a compatible input type, to guarantee that any of the valid types produced can be handled by the destination

Errors

Will return Err if the from or to arrays of DataType are empty, or if the types of the two IO are incompatible