pub struct MetaData {
pub name: String,
pub version: String,
pub description: String,
pub authors: Vec<String>,
}Expand description
MetaData about a flow that will be used in the flow’s description and Manifest
Fields
name: StringThe human readable name of a flow
version: StringSemantic versioning version number of the flow
description: StringA description for humans
The name of the people who authored the flow