Struct flowcore::model::output_connection::OutputConnection
source · pub struct OutputConnection {
pub source: Source,
pub destination_id: usize,
pub destination_io_number: usize,
pub destination_flow_id: usize,
pub destination: String,
}Expand description
OutputConnection contains information about a function’s output connection to another function
Fields
source: SourceSource of the value that should be forwarded
destination_id: usizeid of the destination function of this OutputConnection
destination_io_number: usizeio_number is the IO number the connection is connected to on the destination function
destination_flow_id: usizeflow_id is the flow_id of the target function
destination: Stringdestination is the full route to the destination input
Implementations