Module flowcore::model::validation
source · Expand description
Traits used for the validation of Model structs
Traits
- Many structs in the model implement the
Validatemethod which is used to check the description deserialized from file obeys some additional constraints that cannot be expressed in the struct definition inserde