Enum flowcore::output_connection::Source
source · [−]Expand description
This specifies the Source of an OutputConnection which can either be:
Variants
Output(String)
A subroute of an output of a function - used as JSON pointer to select part of the output
Input(usize)
A copy of the input value used to calculate the job who’s output is being forwarded