Module flowcore::provider

source ·
is a trait definition that providers of content must implement

Traits

  • A content provider is responsible with interfacing with the environment and doing IO or what is required to supply content related with flows - isolating other libraries from the File SSystem or IO. It must implement the Provider trait