defines many of the core data structures used across libraries and binaries
model module defines a number of core data structures that are used across the compiler
and the runtime and macros.
Modules
connectiondefines the connection between one process output to another process’s inputdatatypespecifies the type of data permitted on a input, output or connectionflowis the definition of an entire flow, including children flowsflow_manifestis the struct that specifies the manifest of functions in a flowfunctiondefines a function in a flow or libraryinputdefines the struct for inputs to functions in a flowiois the object used to define a process’s inputs or outputslib_manifestdefines the structs for specifying a Library’s manifest and methods to load itmetadatadefined structs for flow meta datametricsdefines a struct for runtime execution metricsnameis used to name various objects in the flow modeloutput_connectiondefines a struct for a function’s output connectionprocessis a generic definition of afunctionor aflowso a flow referring to it or using it does not need to know or define how it is implementedprocess_referenceis an object used within a flow to reference a process defined elsewhereroutedefines a location in the hierarchy of a flow and can locate a flow, a function, or one of its inputs or outputs- Definition of
RuntimeFunctionstructure submissiondefines a struct for submitting flows for execution- Traits used for the validation of Model structs